==> assert-is-probability-array-0.0.7.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isProbabilityArray

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test if a value is an array-like object containing only probabilities.

<section class="intro">

A **probability** is defined as a numeric value on the interval `[0,1]`.

</section>

<!-- /.intro -->

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-probability-array
```

</section>

<section class="usage">

## Usage

```javascript
var isProbabilityArray = require( '@stdlib/assert-is-probability-array' );
```

#### isProbabilityArray( value )

Tests if a `value` is an array-like object containing **only** probabilities.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );
var Uint8Array = require( '@stdlib/array-uint8' );

var bool = isProbabilityArray( [ 0.6, 0.5, 0.25 ] );
// returns true

bool = isProbabilityArray( [ 0.6, 0.5, new Number( 0.25 ) ] );
// returns true

bool = isProbabilityArray( new Uint8Array( [ 0, 1 ] ) );
// returns true

bool = isProbabilityArray( [ 3.14, 0.0 ] );
// returns false
```

#### isProbabilityArray.primitives( value )

Tests if a `value` is an array-like object `array` containing **only** primitive probabilities.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isProbabilityArray.primitives( [ 1.0, 0.0, 0.8 ] );
// returns true

bool = isProbabilityArray.primitives( [ 0.9, new Number(1.0) ] );
// returns false
```

#### isProbabilityArray.objects( value )

Tests if a `value` is an array-like object `array` containing **only** `Number` objects whose values are probabilities.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isProbabilityArray.objects( [ new Number(1.0), new Number(1.0) ] );
// returns true

bool = isProbabilityArray.objects( [ 1.0, 0.0, 0.6 ] );
// returns false
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var Uint8Array = require( '@stdlib/array-uint8' );
var isProbabilityArray = require( '@stdlib/assert-is-probability-array' );

var arr = [ 0.0, 1.0, 0.5 ];
var bool = isProbabilityArray( arr );
// returns true

arr = [ 0.5, 0.25, 0.25 ];
bool = isProbabilityArray( arr );
// returns true

arr = new Uint8Array( [ 0, 0, 1, 0, 1 ] );
bool = isProbabilityArray( arr );
// returns true

arr = [ 3.14, -1.0 ];
bool = isProbabilityArray( arr );
// returns false

bool = isProbabilityArray( [] );
// returns false

bool = isProbabilityArray( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/assert/is-array`][@stdlib/assert/is-array]</span><span class="delimiter">: </span><span class="description">test if a value is an array.</span>
-   <span class="package-name">[`@stdlib/assert/is-probability`][@stdlib/assert/is-probability]</span><span class="delimiter">: </span><span class="description">test if a value is a probability.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-probability-array.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-probability-array

[test-image]: https://github.com/stdlib-js/assert-is-probability-array/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-probability-array/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-probability-array/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-probability-array?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-probability-array.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-probability-array/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-probability-array/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-probability-array/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-probability-array/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-probability-array/main/LICENSE

<!-- <related-links> -->

[@stdlib/assert/is-array]: https://www.npmjs.com/package/@stdlib/assert-is-array

[@stdlib/assert/is-probability]: https://www.npmjs.com/package/@stdlib/assert-is-probability

<!-- </related-links> -->

</section>

<!-- /.links -->

==> assert-is-probability-array-0.0.8.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isProbabilityArray

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test if a value is an array-like object containing only probabilities.

<section class="intro">

A **probability** is defined as a numeric value on the interval `[0,1]`.

</section>

<!-- /.intro -->

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-probability-array
```

</section>

<section class="usage">

## Usage

```javascript
var isProbabilityArray = require( '@stdlib/assert-is-probability-array' );
```

#### isProbabilityArray( value )

Tests if a `value` is an array-like object containing **only** probabilities.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );
var Uint8Array = require( '@stdlib/array-uint8' );

var bool = isProbabilityArray( [ 0.6, 0.5, 0.25 ] );
// returns true

bool = isProbabilityArray( [ 0.6, 0.5, new Number( 0.25 ) ] );
// returns true

bool = isProbabilityArray( new Uint8Array( [ 0, 1 ] ) );
// returns true

bool = isProbabilityArray( [ 3.14, 0.0 ] );
// returns false
```

#### isProbabilityArray.primitives( value )

Tests if a `value` is an array-like object `array` containing **only** primitive probabilities.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isProbabilityArray.primitives( [ 1.0, 0.0, 0.8 ] );
// returns true

bool = isProbabilityArray.primitives( [ 0.9, new Number(1.0) ] );
// returns false
```

#### isProbabilityArray.objects( value )

Tests if a `value` is an array-like object `array` containing **only** `Number` objects whose values are probabilities.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isProbabilityArray.objects( [ new Number(1.0), new Number(1.0) ] );
// returns true

bool = isProbabilityArray.objects( [ 1.0, 0.0, 0.6 ] );
// returns false
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var Uint8Array = require( '@stdlib/array-uint8' );
var isProbabilityArray = require( '@stdlib/assert-is-probability-array' );

var arr = [ 0.0, 1.0, 0.5 ];
var bool = isProbabilityArray( arr );
// returns true

arr = [ 0.5, 0.25, 0.25 ];
bool = isProbabilityArray( arr );
// returns true

arr = new Uint8Array( [ 0, 0, 1, 0, 1 ] );
bool = isProbabilityArray( arr );
// returns true

arr = [ 3.14, -1.0 ];
bool = isProbabilityArray( arr );
// returns false

bool = isProbabilityArray( [] );
// returns false

bool = isProbabilityArray( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/assert/is-array`][@stdlib/assert/is-array]</span><span class="delimiter">: </span><span class="description">test if a value is an array.</span>
-   <span class="package-name">[`@stdlib/assert/is-probability`][@stdlib/assert/is-probability]</span><span class="delimiter">: </span><span class="description">test if a value is a probability.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-probability-array.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-probability-array

[test-image]: https://github.com/stdlib-js/assert-is-probability-array/actions/workflows/test.yml/badge.svg?branch=v0.0.8
[test-url]: https://github.com/stdlib-js/assert-is-probability-array/actions/workflows/test.yml?query=branch:v0.0.8

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-probability-array/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-probability-array?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-probability-array.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-probability-array/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-probability-array/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-probability-array/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-probability-array/tree/esm
[branches-url]: https://github.com/stdlib-js/assert-is-probability-array/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-probability-array/main/LICENSE

<!-- <related-links> -->

[@stdlib/assert/is-array]: https://www.npmjs.com/package/@stdlib/assert-is-array

[@stdlib/assert/is-probability]: https://www.npmjs.com/package/@stdlib/assert-is-probability

<!-- </related-links> -->

</section>

<!-- /.links -->
